# [pyHXExpress](https://github.com/tuttlelm/pyHXExpress)

*** This is under active development. Please report any issues *** 

This is a python adaptation of [HX-Express](https://www.hxms.com/HXExpress/) [[1]](#1) to perform 
polymodal fits of Hydrogen-Deuterium Exchange Mass Spectrometry (HDX-MS) data. This package can be 
used for high throughput analysis of entire peptide pools and beyond. The pyHXExpress tools can be 
used in python scripts or used interactively within Jupyter Notebooks. The goal of this project is 
to allow users to easily interact with their data and subsequent outputs to gain statistically 
supported insights into the polymodality of the HDX data. 

## How to use this tool
For now just grab the pyhxexpress.py, config.py, and requirements.txt files.
You'll need python 3.8+ and Jupyter Notebook. For additonal dependencies run:


    pip install -r requirements.txt



See Documentation for a guide to analysis. 


### References
<a id="1">[1]</a> 
Guttman M., Weis, D.D., Engen, J.R. & Lee, K. K. (2013).  
Analysis of overlapped and noisy Hydrogen/Deuterium exchange data.  J. Amer. Soc. Mass Spectrom. 24(12), 1906-1912.
[DOI: 10.1007/s13361-013-0727-5](https://pubs.acs.org/doi/10.1007/s13361-013-0727-5).

###### Last edited by LMT on 08April2024
